@@ -213,6 +213,24 @@ def SaveInstance(self):
 			object.append( panelphase.pipelineitems[i].spacer[1].value.GetValue() )
 			object.append( panelphase.pipelineitems[i].spacer[2].value.GetValue() )
 			object.append( panelphase.pipelineitems[i].interp_range.value.GetValue() )
+			object.append( panelphase.pipelineitems[i].bounds[0].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].bounds[1].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].bounds[2].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].bounds[3].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].bounds[4].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].bounds[5].value.GetValue() )
+		if subpanelname == 'Affine Transform':
+			object.append( panelphase.pipelineitems[i].coords_filename.objectpath.GetValue() )
+			object.append( panelphase.pipelineitems[i].outputcoords_filename.objectpath.GetValue() )
+			object.append( panelphase.pipelineitems[i].translate[0].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].translate[1].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].translate[2].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].scale[0].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].scale[1].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].scale[2].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].rotate[0].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].rotate[1].value.GetValue() )
+			object.append( panelphase.pipelineitems[i].rotate[2].value.GetValue() )
 		if subpanelname == 'Voxel Replace':
 			object.append( panelphase.pipelineitems[i].input_filename.objectpath.GetValue() )
 			object.append( panelphase.pipelineitems[i].output_filename.objectpath.GetValue() )
@@ -293,6 +311,8 @@ def SaveInstance(self):
 			object.append( panelphase.pipelineitems[i].feature_angle.value.GetValue() )
 			object.append( panelphase.pipelineitems[i].chkbox_axes.GetValue() )
 			object.append( panelphase.pipelineitems[i].axes_fontfactor.value.GetValue() )
+		if subpanelname == 'Laxarus Viewer':
+			object.append( panelphase.pipelineitems[i].filename.objectpath.GetValue() )
 		if subpanelname == 'View Array':
 			object.append( panelphase.pipelineitems[i].input_filename.objectpath.GetValue() )
 			object.append( panelphase.pipelineitems[i].rbampphase.GetStringSelection() )
@@ -798,6 +818,31 @@ def RestoreInstance(self):
 			panelphase.pipelineitems[-1].spacer[1].value.SetValue(object[4])
 			panelphase.pipelineitems[-1].spacer[2].value.SetValue(object[5])
 			panelphase.pipelineitems[-1].interp_range.value.SetValue(object[6])
+			try:
+				panelphase.pipelineitems[-1].bounds[0].value.SetValue(object[7])
+				panelphase.pipelineitems[-1].bounds[1].value.SetValue(object[8])
+				panelphase.pipelineitems[-1].bounds[2].value.SetValue(object[9])
+				panelphase.pipelineitems[-1].bounds[3].value.SetValue(object[10])
+				panelphase.pipelineitems[-1].bounds[4].value.SetValue(object[11])
+				panelphase.pipelineitems[-1].bounds[5].value.SetValue(object[12])
+			except:
+				pass
+			DoListCheck(panelphase, object, -1)
+		if subpanelname == 'Affine Transform':
+			panelphase.pipelineitems.append(SubPanel_AffineTransform(panelphase.panel2))
+			panelphase.pipelineitems[-1].Hide()
+			panelphase.hbox2.Add(panelphase.pipelineitems[-1], 2, flag=wx.EXPAND|wx.LEFT|wx.RIGHT|wx.TOP, border=10)
+			panelphase.pipelineitems[-1].coords_filename.objectpath.SetValue(object[0])
+			panelphase.pipelineitems[-1].outputcoords_filename.objectpath.SetValue(object[1])
+			panelphase.pipelineitems[-1].translate[0].value.SetValue(object[2])
+			panelphase.pipelineitems[-1].translate[1].value.SetValue(object[3])
+			panelphase.pipelineitems[-1].translate[2].value.SetValue(object[4])
+			panelphase.pipelineitems[-1].scale[0].value.SetValue(object[5])
+			panelphase.pipelineitems[-1].scale[1].value.SetValue(object[6])
+			panelphase.pipelineitems[-1].scale[2].value.SetValue(object[7])
+			panelphase.pipelineitems[-1].rotate[0].value.SetValue(object[8])
+			panelphase.pipelineitems[-1].rotate[1].value.SetValue(object[9])
+			panelphase.pipelineitems[-1].rotate[2].value.SetValue(object[10])
 			DoListCheck(panelphase, object, -1)
 		if subpanelname == 'Voxel Replace':
 			panelphase.pipelineitems.append(SubPanel_Voxel_Replace(panelphase.panel2))
@@ -939,6 +984,11 @@ def RestoreInstance(self):
 			panelphase.pipelineitems[-1].chkbox_axes.SetValue(object[6])
 			panelphase.pipelineitems[-1].axes_fontfactor.value.SetValue(object[7])
 			DoListCheck(panelphase, object, -1)
+		if subpanelname == 'Laxarus Viewer':
+			panelphase.pipelineitems.append(SubPanel_LaxarusView(panelphase.panel2, panelphase.ancestor))
+			panelphase.pipelineitems[-1].Hide()
+			panelphase.hbox2.Add(panelphase.pipelineitems[-1], 2, flag=wx.EXPAND|wx.LEFT|wx.RIGHT|wx.TOP, border=10)
+			panelphase.pipelineitems[-1].filename.objectpath.SetValue(object[0])
 		if subpanelname == 'View Array':
 			panelphase.pipelineitems.append(SubPanel_View_Array(panelphase.panel2, panelphase.ancestor))
 			panelphase.pipelineitems[-1].Hide()
